<?php

namespace Repositories;

use Util\InstanceProvider;

class Operador
{
    /**
     * @param $cdOperador
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getOperatorParams($cdOperador, $nrOrg)
    {
        $query = "SELECT IDSTATUSENHA
                    FROM OPERADOR
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG = :NRORG";

        $params = array(
            'CDOPERADOR' => $cdOperador,
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }

    public function insertControlSenha($cdOperator, $nrOrg, $cdSenhAlt, $cdSenhAltWeb, $idAtuCtrlSenha){
        $currentDate = new \DateTime();
        $currentDate = $currentDate->format('d/m/Y H:i:s');
        $query =  <<<SQL
                    INSERT INTO CONTROLSENHA
                         (NRORGINCLUSAO, DTINCLUSAO, CDOPERINCLUSAO, CDOPERADOR, DTALTSENHA,
                          CDSENHALT, CDSENHALTWEB, IDATUCTRLSENHA, NRORG, DTULTATU, NRORGULTATU, CDOPERULTATU)
                  VALUES (:NRORG, TO_DATE(:NOW,'DD/MM/YYYY HH24:MI:SS'), :CDOPERADOR, :CDOPERADOR, TO_DATE(:NOW,'DD/MM/YYYY HH24:MI:SS'),
                          :CDSENHALT, :CDSENHALTWEB, :IDATUCTRLSENHA, :NRORG, TO_DATE(:NOW,'DD/MM/YYYY HH24:MI:SS'), :NRORG, :CDOPERADOR)
SQL;

        $params = array(
            'CDOPERADOR'     => $cdOperator,
            'NRORG'          => $nrOrg,
            'CDSENHALT'      => $cdSenhAlt,
            'CDSENHALTWEB'   => $cdSenhAltWeb,
            "NOW"            => $currentDate,
            'IDATUCTRLSENHA' => $idAtuCtrlSenha
        );
        $entityManager =  InstanceProvider::getEntityManager();
        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    public function updateOperatorPasswordSaas($cdOperator, $nrOrg, $webPassword, $delphiPassword)
    {
        $dateTimeFormat = 'DD/MM/YYYY HH24:MI:SS';
        $currentDate = new \DateTime();
        $currentDate = $currentDate->format('d/m/Y H:i:s');
        $query = <<<SQL
                    UPDATE OPERADOR
                     SET CDSENHAOPERWEB = :WEB_PASSWORD,
                         CDSENHOPER     = :DELPHI_PASSWORD,
                         DTULTATU       = TO_DATE(:DTULTATU,'$dateTimeFormat'),
                         IDSTATUSENHA   = 'A'
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG      = :NRORG
SQL;

        $params = array(
            'CDOPERADOR' => $cdOperator,
            'NRORG' => $nrOrg,
            'DTULTATU' => $currentDate,
            'WEB_PASSWORD' => $webPassword,
            'DELPHI_PASSWORD' => $delphiPassword
        );


        $entityManager =  InstanceProvider::getEntityManager();
        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    public function getOperatorByNmAccessOrEmail($operador,$nrorg){
        $query =
            <<<SQL
                SELECT CDOPERADOR AS "ID", NMOPERADOR AS "NAME", NRORG AS "ORGANIZATION_ID", DSEMAILOPER AS "EMAIL",
                         CDSENHAOPERWEB AS "PASSWORD_MD5", CDSENHOPER AS "PASSWORD_CRYPTO_PLUS",
                         CASE WHEN IDOPERATIVO = 'A'
                              THEN 'Y'
                              ELSE 'N'
                          END AS "IS_ACTIVE",
                         IDIDIOMA AS "IDIDIOMA", NMACESSO AS "NMACESSO", NMCOMPLOPER AS "NMCOMPLOPER", CDEMPRESA AS "CDEMPRESA", NRPARCNEGOCIO AS "NRPARCNEGOCIO",
                        NRORG AS "NRORG", NRORGTRAB AS "NRORGTRAB", NRESTRUTTRAB AS "NRESTRUTTRAB", CDFILIALSELECIONADA AS "CDFILIALSELECIONADA", NRORGOPER AS "NRORGOPER"
                    FROM OPERADOR
                   WHERE UPPER(NMACESSO) = UPPER(:OPERADOR)
                      OR DSEMAILOPER = :OPERADOR
SQL;


        $params = array( 'OPERADOR' => $operador );

        $entityManager =  InstanceProvider::getEntityManager();
        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }

    /**
     * @param $cdOperador
     * @param $nrOrg
     * @param $idStatuSenha
     * @return \Doctrine\DBAL\Driver\Statement
     * @throws \Doctrine\DBAL\DBALException
     */
    public function saveOperatorPasswordStatus($cdOperador, $nrOrg, $idStatuSenha)
    {
        $query = "UPDATE OPERADOR
                     SET IDSTATUSENHA = :IDSTATUSENHA
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG = :NRORG";

        $params = array(
            'IDSTATUSENHA' => $idStatuSenha,
            'CDOPERADOR' => $cdOperador,
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    /**
     * @param $nrParcNegocio
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getOperatorAccessProfile($nrParcNegocio, $nrOrg)
    {
        $query = "SELECT PP.NRPERFILACESSO AS ID, PA.IDPERFILACESSOADM
                    FROM PERFACESSPARC PP
              INNER JOIN PERFILACESSO PA ON PA.NRPERFILACESSO = PP.NRPERFILACESSO
                   WHERE PP.NRORG = :NRORG
                     AND PP.NRPARCNEGOCIO = :NRPARCNEGOCIO
                     AND PP.IDATIVO = 'S'
                     AND (PP.DTVALIDADE IS NULL OR TRUNC(PP.DTVALIDADE) >= TRUNC(SYSDATE))";

        $params = array(
            'NRPARCNEGOCIO' => $nrParcNegocio,
            'NRORG' => $nrOrg
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->fetchAll($query, $params);
    }

    /**
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getBranchAccessProfile($userId, $nrOrg)
    {
        $query = "SELECT DISTINCT PP.NRPERFILACESSO AS ID, PA.IDPERFILACESSOADM
                    FROM PERFACESSFILI PP
              INNER JOIN PERFILACESSO PA ON PA.NRPERFILACESSO = PP.NRPERFILACESSO
                   WHERE PP.NRORG = :NRORG
                     AND PP.CDOPERADOR = :CDOPERADOR
                     AND PP.IDATIVO = 'S'
                     AND (PP.DTVALIDADE IS NULL OR TRUNC(PP.DTVALIDADE) >= TRUNC(SYSDATE))";

        $params = array(
            'NRORG'      => $nrOrg,
            'CDOPERADOR' => $userId
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->fetchAll($query, $params);
    }

    /**
     * @param $nrOrg
     * @return array
     * @throws \Exception
     */
    public function getIdUtlPerfilFilialParamGeral($nrOrg)
    {
        $query = "SELECT IDUTLPERFILFILIAL
                    FROM PARAMGERAL
                   WHERE NRORG = :NRORG";

        $params = array('NRORG' => $nrOrg);

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        try {
            $result = $entityManager->getConnection()->fetchAll($query, $params);
            return !empty($result) ? $result[0] : $result;
        } catch (\Exception $e) {
            return array(
                'IDUTLPERFILFILIAL' => "N"
            );
        }
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @return array
     * @throws \Exception
     */
    public function getCdPerfilSelecionado($nrOrg, $cdOperator)
    {
        $query = "SELECT OP.CDPERFILSELECIONADO AS ID, PA.IDPERFILACESSOADM
                    FROM OPERADOR OP
              INNER JOIN PERFILACESSO PA ON PA.NRPERFILACESSO = OP.CDPERFILSELECIONADO
                   WHERE OP.NRORG = :NRORG
                     AND OP.CDOPERADOR = :CDOPERADOR";

        $params = array('NRORG' => $nrOrg, 'CDOPERADOR' => $cdOperator);

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        try {
            return $entityManager->getConnection()->fetchAll($query, $params);
        } catch (\Exception $e) {
            return array(
                array(
                    'ID' => null, 'IDPERFILACESSOADM' => 'N'
                )
            );
        }
    }

    /**
     * @param $cdoperador
     * @param $nrorg
     * @return \Doctrine\DBAL\Driver\ResultStatement
     * @throws \Exception
     */
    public function updateLastAccess($cdoperador, $nrorg)
    {
        $query = "UPDATE OPERADOR
                     SET DTULTACESOPER = SYSDATE
                   WHERE CDOPERADOR = :CDOPERADOR
                     AND NRORG = :NRORG";

        $params = array(
            'CDOPERADOR' => $cdoperador,
            'NRORG' => $nrorg
        );
        try {
            $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrorg);
            $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

            return $entityManager->getConnection()->executeQuery($query, $params);
        } catch (\Exception $e) {
            throw new \Exception($e->getMessage());
        };
    }

    /**
     * @param $nrOrg
     * @param $cdOperator
     * @return array
     * @throws \Exception
     */
    public function insertBranchesSupportOperator($nrOrg, $cdOperator)
    {
        $query = "INSERT INTO FILIOPER (CDOPERADOR, CDFILIAL, NRORG)
                       SELECT :CDOPERADOR, CDFILIAL, :NRORG
                         FROM FILIAL
                        WHERE IDATIVO = 'S'
                          AND NRORG = :NRORG
                          AND CDFILIAL NOT IN (SELECT CDFILIAL
                                                 FROM FILIOPER
                                                WHERE CDOPERADOR = :CDOPERADOR
                                                  AND NRORG = :NRORG)";

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($nrOrg);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        $params = array('NRORG' => $nrOrg, 'CDOPERADOR' => $cdOperator);
        return $entityManager->getConnection()->executeQuery($query, $params);
    }

    public function insertLogOpera($idTipoOper, $dsOperacao, $cdPesqItem, $dsEndUsuOper, $dsNmUsuOper, $organizationId, $operatorCode, $operatorName) {
        $query = "INSERT INTO LOGOPERA
                         (NMTABELA, DTOPERACAO, NMRESPOPER, IDTIPOOPER, DSOPERACAO, CDPESQITEM, DSRDMUSUOPER, 
                          DSENDUSUOPER, DSNMUSUOPER, DSMETUSUOPER, CDORESPOPER, CDFILLOGOPER, 
                          NRORG, DTINCLUSAO, DTULTATU, NRORGINCLUSAO, CDOPERINCLUSAO, NRORGULTATU, CDOPERULTATU, IDATIVO)
                  VALUES ('OPERADOR', SYSDATE, :NMOPERADOR, :IDTIPOOPER, :DSOPERACAO, :CDPESQITEM, 'LOGIN',
                          :DSENDUSUOPER, :DSNMUSUOPER, 'Login', :CDOPERADOR, NULL,
                          :NRORG, SYSDATE, SYSDATE, :NRORG, :CDOPERADOR, :NRORG, :CDOPERADOR, 'S')";

        $params = array(
            'IDTIPOOPER'   => $idTipoOper,
            'DSOPERACAO'   => substr($dsOperacao, 0, 700),
            'CDPESQITEM'   => substr($cdPesqItem, 0, 80),
            'DSENDUSUOPER' => substr($dsEndUsuOper, 0, 50),
            'DSNMUSUOPER'  => substr($dsNmUsuOper, 0, 50),
            'NRORG'        => $organizationId,
            'CDOPERADOR'   => $operatorCode,
            'NMOPERADOR'   => substr($operatorName, 0, 40),
        );

        $entityManager = InstanceProvider::getLibConnectionCustom()->updateVpdConnection($organizationId);
        $entityManager = $entityManager ? $entityManager : InstanceProvider::getEntityManager();

        return $entityManager->getConnection()->executeQuery($query, $params);
    }
}